==> gdc-0.15.tar.bz2: d/phobos/gcc/cbridge_math.c <==
/* GDC -- D front-end for GCC
   Copyright (C) 2004 David Friedman
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <math.h>
#include "config.h"

/*
#if HAVE_DISTINCT_LONG_DOUBLE
typedef long double my_long_double;
#else
typedef double my_long_double;
#endif
*/
typedef long double my_long_double;

#ifdef _AIX
/* must match with gen_math.c */
#include "aix_float.h"
#undef   fpclassify
static int our_fpclassify(double v)
{
    switch (class(v)) {

    case FP_PLUS_NORM:
    case FP_MINUS_NORM:
        return FP_PLUS_NORM;
    case FP_PLUS_ZERO:
    case FP_MINUS_ZERO:
	return FP_PLUS_ZERO;
    case FP_PLUS_INF:
    case FP_MINUS_INF:
	return FP_PLUS_INF;
    case FP_PLUS_DENORM:
    case FP_MINUS_DENORM:
	return FP_PLUS_DENORM;
    case FP_SNAN:
    case FP_QNAN:
	return FP_SNAN;
	// default
    }
}
#define  fpclassify our_fpclassify

#undef  signbit
static int our_signbit(double v)
{
    return *(int*)(&v) < 0;
}
#define signbit our_signbit

#endif

#define XFUNC(name) \
int _d_gnu_cbridge_##name##l(my_long_double v) { return name(v); } \
int _d_gnu_cbridge_##name##d(double v) { return name(v); } \
int _d_gnu_cbridge_##name##f(float v) { return name(v); }

XFUNC(fpclassify)
XFUNC(signbit)

/* can add the others with config tests, buf for now,
   just use fpclassify */

==> gdc-0.17.tar.bz2: d/phobos/gcc/cbridge_math.c <==
/* GDC -- D front-end for GCC
   Copyright (C) 2004 David Friedman
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <math.h>
#include "config.h"

/*
#if HAVE_DISTINCT_LONG_DOUBLE
typedef long double my_long_double;
#else
typedef double my_long_double;
#endif
*/
typedef long double my_long_double;

#ifdef _AIX
/* must match with gen_math.c */
#include "aix_float.h"
#undef   fpclassify
static int our_fpclassify(double v)
{
    switch (class(v)) {

    case FP_PLUS_NORM:
    case FP_MINUS_NORM:
        return FP_PLUS_NORM;
    case FP_PLUS_ZERO:
    case FP_MINUS_ZERO:
	return FP_PLUS_ZERO;
    case FP_PLUS_INF:
    case FP_MINUS_INF:
	return FP_PLUS_INF;
    case FP_PLUS_DENORM:
    case FP_MINUS_DENORM:
	return FP_PLUS_DENORM;
    case FP_SNAN:
    case FP_QNAN:
	return FP_SNAN;
	// default
    }
}
#define  fpclassify our_fpclassify

#undef  signbit
static int our_signbit(double v)
{
    return *(int*)(unsigned char *)(&v) < 0;
}
#define signbit our_signbit

#endif

#define XFUNC(name) \
int _d_gnu_cbridge_##name##l(my_long_double v) { return name(v); } \
int _d_gnu_cbridge_##name##d(double v) { return name(v); } \
int _d_gnu_cbridge_##name##f(float v) { return name(v); }

XFUNC(fpclassify)
XFUNC(signbit)

/* can add the others with config tests, buf for now,
   just use fpclassify */
